Res

Struct Res 

pub struct Res(/* private fields */);
Pixel resolution of a given texture. The resolution is stored in log form: ulog2 = log2(ures), vlog2 = log2(vres)). Note: negative ulog2 or vlog2 values are reserved for internal use.

Implementations

Source

impl Res

pub fn from_uv(u: i8, v: i8) -> Self

pub fn from_value(value: u16) -> Self

pub fn clone_swapped(&self) -> Self

Get value of resolution with u and v swapped.

pub fn size(&self) -> usize

Total size of specified texture in texels (u * v).

pub fn u(&self) -> i32

U resolution in texels.

pub fn v(&self) -> i32

V resolution in texels.

pub fn value(&self) -> u16

Resolution as a single 16-bit integer value.

pub fn swap_uv(&mut self)

Swap the u and v resolution values in place.

pub fn clamp(&mut self, res: Res)

Clamp the resolution value against the given value.

pub fn ntilesu(&self, tileres: Res) -> i32

Determine the number of tiles in the u direction for the given tile res.

pub fn ntilesv(&self, tileres: Res) -> i32

Determine the number of tiles in the v direction for the given tile res.

pub fn ntiles(&self, tileres: Res) -> i32

Determine the total number of tiles for the given tile res.