pub struct Res(/* private fields */);Expand description
Pixel resolution of a given texture. The resolution is stored in log form: ulog2 = log2(ures), vlog2 = log2(vres)). Note: negative ulog2 or vlog2 values are reserved for internal use.
Implementations
Sourceimpl Res
impl Res
pub fn from_uv(u: i8, v: i8) -> Self
pub fn from_value(value: u16) -> Self
Sourcepub fn clone_swapped(&self) -> Self
pub fn clone_swapped(&self) -> Self
Get value of resolution with u and v swapped.
Sourcepub fn ntilesu(&self, tileres: Res) -> i32
pub fn ntilesu(&self, tileres: Res) -> i32
Determine the number of tiles in the u direction for the given tile res.